# Web Builder

Setting up new projects sucks. This helps.
=============

## Getting Started

Web Builder is easy to set up and run and has no package dependencies.

### Prerequisites

```
Python 3.6
```

### Installing

Install the package through the pip package manager

```
pip install webbuilder
```

That's it! Now you'll be able to pull it up with a simple command from anywhere (unless modified, code is always deposited on Desktop)
```
python webbuilder
```

## Built With

* [Atom](https://atom.io/) - The best IDE on Windows
* [The Guess and Check Method](https://en.wikipedia.org/wiki/Trial_and_error) - It works flawlessly in the end, isn't that all that matters?


## Author
* **Taylor Satula** - *Initial work* - [GitHub](https://github.com/taylorsatula)

## License

This project is licensed under the MIT License - see the [LICENSE.md](LICENSE.md) file for details

## Acknowledgments

* Syed Raza
* GroupMe
* Unbridled ADHD
* The Fans
